==> cuteradio_0.0.1.tar.gz: cuteradio-0.0.1/src/maemo5/mainwindow.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "stackedwindow.h"

class HomescreenModel;
class SearchListModel;
class ListView;
class QModelIndex;
class QVBoxLayout;
class QLineEdit;
class NowPlayingButton;

class MainWindow : public StackedWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);

private slots:
    void onItemClicked(const QModelIndex &index);

    void searchStations();
    void showGenres();
    void showCountries();
    void showLanguages();
    void showRecentlyPlayedStations();
    void showFavouriteStations();

    void showAddStationDialog();
    void showSettingsDialog();
    void showAboutDialog();

    void showInformationBanner(const QString &message);

private:
    HomescreenModel *m_model;
    SearchListModel *m_searchModel;

    QLineEdit *m_searchEdit;

    ListView *m_view;

    QVBoxLayout *m_vbox;

    NowPlayingButton *m_nowPlayingButton;
};

#endif // MAINWINDOW_H

==> cuteradio_0.2.0.tar.gz: cuteradio-0.2.0/src/maemo5/mainwindow.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "stackedwindow.h"

class HomescreenModel;
class SearchListModel;
class ListView;
class QModelIndex;
class QGridLayout;
class QLineEdit;
class QProgressDialog;
class NowPlayingButton;
class ValueSelector;

class MainWindow : public StackedWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);

private slots:
    void onItemClicked(const QModelIndex &index);

    void onSearchTypeChanged(const QVariant &type);

    void search();
    void searchStations();
    void searchPodcasts();
    void showGenres();
    void showCountries();
    void showLanguages();
    void showRecentlyPlayedStations();
    void showFavouriteStations();
    void showPodcasts();
    void showTuneIn();

    void showAddStationDialog();
    void showAddPodcastDialog();
    void showPlayStationDialog();
    void showSettingsDialog();
    void showAboutDialog();

    void showInformationBanner(const QString &message);

    void showProgressDialog(const QString &message, int numberOfOperations = 1);
    void updateProgressDialog(int progress);
    void cancelProgressDialog();

private:
    HomescreenModel *m_model;
    SearchListModel *m_searchModel;

    QLineEdit *m_searchEdit;

    ValueSelector *m_searchTypeSelector;

    ListView *m_view;

    QGridLayout *m_grid;

    NowPlayingButton *m_nowPlayingButton;

    QProgressDialog *m_progressDialog;
};

#endif // MAINWINDOW_H
